Method: FormatR::Format#setBottom

Defined in:
lib/formatr.rb

#setBottom(format) ⇒ Object

Set a format to print at the end of a page. This is tricky and you should be careful using it. It currently has problems on short pages (at least). In order for a bottom to show up you need to finish off a page. This means that formats less than a page will need to be finished off with a call to one of the finishPageWithFF methods.

Raises:



749
750
751
752
753
754
755
756
757
758
759
# File 'lib/formatr.rb', line 749

def setBottom (format)
  bottom_format = format
  if (!format.is_a?(Format))
    bottom_format = Format.new(format);
  end
  raise FormatException, "recursive format not allowed" if (bottom_format == self)
  @bottom = bottom_format
  #in case we've already set use_hash
  useHash( @use_hash )

end